import { batch } from '@preact/signals-react';
import { isFieldDirty } from './isFieldDirty';
import { updateFormDirty } from './updateFormDirty';
/**
 * Updates the dirty state of a field.
 *
 * @param form The form of the field.
 * @param field The store of the field.
 */
export function updateFieldDirty(form, field) {
    // Check if field is dirty
    const dirty = isFieldDirty(field.startValue.peek(), field.value.peek());
    // Update dirty state of field if necessary
    if (dirty !== field.dirty.peek()) {
        batch(() => {
            field.dirty.value = dirty;
            // Update dirty state of form
            updateFormDirty(form, dirty);
        });
    }
}
